==> ponyc-0.21.2-1-x86_64.pkg.tar.xz: usr/share/doc/pony/stdlib-docs/docs/cli-CommandSpec.md <==
# CommandSpec

CommandSpec describes the specification of a parent or leaf command. Each
command has the following attributes:

- a name: a simple string token that identifies the command.
- a description: used in the syntax message.
- a map of options: the valid options for this command.
- an optional help option+command name for help parsing
- one of:
   - a Map of child commands.
   - an Array of arguments.


```pony
class ref CommandSpec
```

## Constructors

### parent

```pony
new ref parent(
  name': String val,
  descr': String val = seq,
  options': Array[OptionSpec val] box = seq,
  commands': Array[CommandSpec ref] box = seq)
: CommandSpec ref^ ?
```
#### Parameters

*   name': [String](builtin-String) val
*   descr': [String](builtin-String) val = seq
*   options': [Array](builtin-Array)\[[OptionSpec](cli-OptionSpec) val\] box = seq
*   commands': [Array](builtin-Array)\[[CommandSpec](cli-CommandSpec) ref\] box = seq

#### Returns

* [CommandSpec](cli-CommandSpec) ref^ ?

---

### leaf

```pony
new ref leaf(
  name': String val,
  descr': String val = seq,
  options': Array[OptionSpec val] box = seq,
  args': Array[ArgSpec val] box = seq)
: CommandSpec ref^ ?
```
#### Parameters

*   name': [String](builtin-String) val
*   descr': [String](builtin-String) val = seq
*   options': [Array](builtin-Array)\[[OptionSpec](cli-OptionSpec) val\] box = seq
*   args': [Array](builtin-Array)\[[ArgSpec](cli-ArgSpec) val\] box = seq

#### Returns

* [CommandSpec](cli-CommandSpec) ref^ ?

---

## Public Functions

### add_command

Adds an additional child command to this parent command.


```pony
fun ref add_command(
  cmd: CommandSpec box)
: None val ?
```
#### Parameters

*   cmd: [CommandSpec](cli-CommandSpec) box

#### Returns

* [None](builtin-None) val ?

---

### add_help

Adds a standard help option and, optionally command, to a root command.


```pony
fun ref add_help(
  hname: String val = seq)
: None val ?
```
#### Parameters

*   hname: [String](builtin-String) val = seq

#### Returns

* [None](builtin-None) val ?

---

### name

Returns the name of this command.


```pony
fun box name()
: String val
```

#### Returns

* [String](builtin-String) val

---

### descr

Returns the description for this command.


```pony
fun box descr()
: String val
```

#### Returns

* [String](builtin-String) val

---

### options

Returns a map by name of the named options of this command.


```pony
fun box options()
: HashMap[String val, OptionSpec val, HashEq[String val] val] box
```

#### Returns

* [HashMap](collections-HashMap)\[[String](builtin-String) val, [OptionSpec](cli-OptionSpec) val, [HashEq](collections-HashEq)\[[String](builtin-String) val\] val\] box

---

### commands

Returns a map by name of the child commands of this command.


```pony
fun box commands()
: HashMap[String val, CommandSpec box, HashEq[String val] val] box
```

#### Returns

* [HashMap](collections-HashMap)\[[String](builtin-String) val, [CommandSpec](cli-CommandSpec) box, [HashEq](collections-HashEq)\[[String](builtin-String) val\] val\] box

---

### args

Returns an array of the positional arguments of this command.


```pony
fun box args()
: Array[ArgSpec val] box
```

#### Returns

* [Array](builtin-Array)\[[ArgSpec](cli-ArgSpec) val\] box

---

### help_name

Returns the name of the help command, which defaults to "help".


```pony
fun box help_name()
: String val
```

#### Returns

* [String](builtin-String) val

---

### help_string

Returns a formated help string for this command and all of its arguments.


```pony
fun box help_string()
: String val
```

#### Returns

* [String](builtin-String) val

---

## Private Functions

### _assertName

```pony
fun tag _assertName(
  nm: String val)
: String val ?
```
#### Parameters

*   nm: [String](builtin-String) val

#### Returns

* [String](builtin-String) val ?

---

==> ponyc-0.22.3-1-x86_64.pkg.tar.xz: usr/share/doc/pony/stdlib-docs/docs/cli-CommandSpec.md <==
# CommandSpec
<span class="source-link">[[Source]](src/cli/command_spec.md#L4)</span>

CommandSpec describes the specification of a parent or leaf command. Each
command has the following attributes:

- a name: a simple string token that identifies the command.
- a description: used in the syntax message.
- a map of options: the valid options for this command.
- an optional help option+command name for help parsing
- one of:
   - a Map of child commands.
   - an Array of arguments.


```pony
class ref CommandSpec
```

## Constructors

### parent
<span class="source-link">[[Source]](src/cli/command_spec.md#L27)</span>


Creates a command spec that can accept options and child commands, but not
arguments.


```pony
new ref parent(
  name': String val,
  descr': String val = seq,
  options': Array[OptionSpec val] box = seq,
  commands': Array[CommandSpec ref] box = seq)
: CommandSpec ref^ ?
```
#### Parameters

*   name': [String](builtin-String) val
*   descr': [String](builtin-String) val = seq
*   options': [Array](builtin-Array)\[[OptionSpec](cli-OptionSpec) val\] box = seq
*   commands': [Array](builtin-Array)\[[CommandSpec](cli-CommandSpec) ref\] box = seq

#### Returns

* [CommandSpec](cli-CommandSpec) ref^ ?

---

### leaf
<span class="source-link">[[Source]](src/cli/command_spec.md#L46)</span>


Creates a command spec that can accept options and arguments, but not child
commands.


```pony
new ref leaf(
  name': String val,
  descr': String val = seq,
  options': Array[OptionSpec val] box = seq,
  args': Array[ArgSpec val] box = seq)
: CommandSpec ref^ ?
```
#### Parameters

*   name': [String](builtin-String) val
*   descr': [String](builtin-String) val = seq
*   options': [Array](builtin-Array)\[[OptionSpec](cli-OptionSpec) val\] box = seq
*   args': [Array](builtin-Array)\[[ArgSpec](cli-ArgSpec) val\] box = seq

#### Returns

* [CommandSpec](cli-CommandSpec) ref^ ?

---

## Public Functions

### add_command
<span class="source-link">[[Source]](src/cli/command_spec.md#L76)</span>


Adds an additional child command to this parent command.


```pony
fun ref add_command(
  cmd: CommandSpec box)
: None val ?
```
#### Parameters

*   cmd: [CommandSpec](cli-CommandSpec) box

#### Returns

* [None](builtin-None) val ?

---

### add_help
<span class="source-link">[[Source]](src/cli/command_spec.md#L83)</span>


Adds a standard help option and, optionally command, to a root command.


```pony
fun ref add_help(
  hname: String val = seq,
  descr': String val = seq)
: None val ?
```
#### Parameters

*   hname: [String](builtin-String) val = seq
*   descr': [String](builtin-String) val = seq

#### Returns

* [None](builtin-None) val ?

---

### name
<span class="source-link">[[Source]](src/cli/command_spec.md#L98)</span>


Returns the name of this command.


```pony
fun box name()
: String val
```

#### Returns

* [String](builtin-String) val

---

### descr
<span class="source-link">[[Source]](src/cli/command_spec.md#L104)</span>


Returns the description for this command.


```pony
fun box descr()
: String val
```

#### Returns

* [String](builtin-String) val

---

### options
<span class="source-link">[[Source]](src/cli/command_spec.md#L110)</span>


Returns a map by name of the named options of this command.


```pony
fun box options()
: HashMap[String val, OptionSpec val, HashEq[String val] val] box
```

#### Returns

* [HashMap](collections-HashMap)\[[String](builtin-String) val, [OptionSpec](cli-OptionSpec) val, [HashEq](collections-HashEq)\[[String](builtin-String) val\] val\] box

---

### commands
<span class="source-link">[[Source]](src/cli/command_spec.md#L116)</span>


Returns a map by name of the child commands of this command.


```pony
fun box commands()
: HashMap[String val, CommandSpec box, HashEq[String val] val] box
```

#### Returns

* [HashMap](collections-HashMap)\[[String](builtin-String) val, [CommandSpec](cli-CommandSpec) box, [HashEq](collections-HashEq)\[[String](builtin-String) val\] val\] box

---

### args
<span class="source-link">[[Source]](src/cli/command_spec.md#L122)</span>


Returns an array of the positional arguments of this command.


```pony
fun box args()
: Array[ArgSpec val] box
```

#### Returns

* [Array](builtin-Array)\[[ArgSpec](cli-ArgSpec) val\] box

---

### help_name
<span class="source-link">[[Source]](src/cli/command_spec.md#L128)</span>


Returns the name of the help command, which defaults to "help".


```pony
fun box help_name()
: String val
```

#### Returns

* [String](builtin-String) val

---

### help_string
<span class="source-link">[[Source]](src/cli/command_spec.md#L134)</span>


Returns a formated help string for this command and all of its arguments.


```pony
fun box help_string()
: String val
```

#### Returns

* [String](builtin-String) val

---

## Private Functions

### _assertName
<span class="source-link">[[Source]](src/cli/command_spec.md#L65)</span>


```pony
fun tag _assertName(
  nm: String val)
: String val ?
```
#### Parameters

*   nm: [String](builtin-String) val

#### Returns

* [String](builtin-String) val ?

---
